@@ -233,6 +233,18 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
 
     # Public methods ----------------------------------------------------------
 
+    @classmethod
+    def clear_extensions(cls) -> None:
+        """ Clear any currently defined custom extensions.
+
+        Serialization calls will result in any currently defined custom
+        extensions being included with the generated Document, whether or not
+        there are utlized. This method can be used to clear out all existing
+        custom extension definitions.
+
+        """
+        _default_resolver.clear_extensions()
+
     @classmethod
     @without_property_validation
     def parameters(cls: type[Model]) -> list[Parameter]:
@@ -343,7 +355,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
             other_attr (str) :
                 The property on ``other`` to link together
 
-            attr_selector (Union[int, str]) :
+            attr_selector (int | str) :
                 The index to link an item in a subscriptable ``attr``
 
         Added in version 1.1
@@ -394,7 +406,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
             raise ValueError(f"{attr!r} is not a property of self ({self!r})")
 
         if not isinstance(other, Model):
-            raise ValueError("'other' is not a Bokeh model: %r" % other)
+            raise ValueError(f"'other' is not a Bokeh model: {other!r}")
 
         other_descriptor = other.lookup(other_attr, raises=False)
         if other_descriptor is None:
@@ -587,10 +599,6 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
         self.document = doc
         self._update_event_callbacks()
 
-    @classmethod
-    def _clear_extensions(cls) -> None:
-        _default_resolver.clear_extensions()
-
     def _detach_document(self) -> None:
         ''' Detach a model from a Bokeh |Document|.
 
