@@ -449,7 +449,7 @@ class Plot(LayoutDOM):
         if not self.x_range: missing.append('x_range')
         if not self.y_range: missing.append('y_range')
         if missing:
-            return ", ".join(missing) + " [%s]" % self
+            return ", ".join(missing) + f" [{self}]"
 
     @error(REQUIRED_SCALE)
     def _check_required_scale(self) -> str | None:
@@ -457,7 +457,7 @@ class Plot(LayoutDOM):
         if not self.x_scale: missing.append('x_scale')
         if not self.y_scale: missing.append('y_scale')
         if missing:
-            return ", ".join(missing) + " [%s]" % self
+            return ", ".join(missing) + f" [{self}]"
 
     @error(INCOMPATIBLE_SCALE_AND_RANGE)
     def _check_compatible_scale_and_ranges(self) -> str | None:
@@ -469,20 +469,20 @@ class Plot(LayoutDOM):
 
         if self.x_scale is not None:
             for rng in x_ranges:
-                if isinstance(rng, (DataRange1d, Range1d)) and not isinstance(self.x_scale, (LinearScale, LogScale)):
+                if isinstance(rng, DataRange1d | Range1d) and not isinstance(self.x_scale, LinearScale | LogScale):
                     incompatible.append(f"incompatibility on x-dimension: {rng}, {self.x_scale}")
                 elif isinstance(rng, FactorRange) and not isinstance(self.x_scale, CategoricalScale):
                     incompatible.append(f"incompatibility on x-dimension: {rng}, {self.x_scale}")
 
         if self.y_scale is not None:
             for rng in y_ranges:
-                if isinstance(rng, (DataRange1d, Range1d)) and not isinstance(self.y_scale, (LinearScale, LogScale)):
+                if isinstance(rng, DataRange1d | Range1d) and not isinstance(self.y_scale, LinearScale | LogScale):
                     incompatible.append(f"incompatibility on y-dimension: {rng}, {self.y_scale}")
                 elif isinstance(rng, FactorRange) and not isinstance(self.y_scale, CategoricalScale):
                     incompatible.append(f"incompatibility on y-dimension: {rng}, {self.y_scale}")
 
         if incompatible:
-            return ", ".join(incompatible) + " [%s]" % self
+            return ", ".join(incompatible) + f" [{self}]"
 
     @warning(MISSING_RENDERERS)
     def _check_missing_renderers(self) -> str | None:
@@ -516,17 +516,6 @@ class Plot(LayoutDOM):
     The (default) data range of the vertical dimension of the plot.
     """)
 
-    @classmethod
-    def _scale(cls, scale: Literal["auto", "linear", "log", "categorical"]) -> Scale:
-        if scale in ["auto", "linear"]:
-            return LinearScale()
-        elif scale == "log":
-            return LogScale()
-        if scale == "categorical":
-            return CategoricalScale()
-        else:
-            raise ValueError(f"Unknown mapper_type: {scale}")
-
     x_scale = Instance(Scale, default=InstanceDefault(LinearScale), help="""
     What kind of scale to use to convert x-coordinates in data space
     into x-coordinates in screen space.
@@ -920,7 +909,7 @@ class _list_attr_splat(list):
         if attr in dir(list):
             return list.__getattribute__(self, attr)
         if len(self) == 0:
-            raise AttributeError("Trying to access %r attribute on an empty 'splattable' list" % attr)
+            raise AttributeError(f"Trying to access {attr!r} attribute on an empty 'splattable' list")
         if len(self) == 1:
             return getattr(self[0], attr)
         try:
