@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,6 +22,7 @@ from typing import TYPE_CHECKING, Any
 
 # Bokeh imports
 from ..models import glyphs
+from ..util.deprecation import deprecated
 from ._decorators import glyph_method, marker_method
 
 if TYPE_CHECKING:
@@ -71,7 +72,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.annulus(x=[1, 2, 3], y=[1, 2, 3], color="#7FC97F",
@@ -92,7 +93,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.asterisk(x=[1,2,3], y=[1,2,3], size=20, color="#F0027F")
@@ -106,24 +107,46 @@ Examples:
         pass
 
     @glyph_method(glyphs.Circle)
+    def _circle(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        pass
+
     def circle(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """ Configure and add :class:`~bokeh.models.glyphs.Circle` glyphs to this figure.
+
+        Args:
+            x (str or seq[float]) : values or field names of center x coordinates
+
+            y (str or seq[float]) : values or field names of center y coordinates
+
+            radius (str or list[float]) : values or field names of radii in |data units|
+
+            color (color value, optional): shorthand to set both fill and line color
+
+            source (:class:`~bokeh.models.sources.ColumnDataSource`) : a user-supplied data source.
+                An attempt will be made to convert the object to :class:`~bokeh.models.sources.ColumnDataSource`
+                if needed. If none is supplied, one is created for the user automatically.
+
+            **kwargs: |line properties| and |fill properties|
+
+        Examples:
+
+            .. code-block:: python
+
+                from bokeh.plotting import figure, show
+
+                plot = figure(width=300, height=300)
+                plot.circle(x=[1, 2, 3], y=[1, 2, 3], radius=0.2)
+
+                show(plot)
+
         """
-.. note::
-    Only one of ``size`` or ``radius`` should be provided. Note that ``radius``
-    defaults to |data units|.
-
-Examples:
-
-    .. code-block:: python
-
-        from bokeh.plotting import figure, output_file, show
-
-        plot = figure(width=300, height=300)
-        plot.circle(x=[1, 2, 3], y=[1, 2, 3], size=20)
-
-        show(plot)
-
-"""
+        if "size" in kwargs:
+            deprecated((3, 4, 0), "circle() method with size value", "scatter(size=...) instead")
+            if "radius" in kwargs:
+                raise ValueError("can only provide one of size or radius")
+            return self.scatter(*args, **kwargs)
+        else:
+            return self._circle(*args, **kwargs)
 
     @glyph_method(glyphs.Block)
     def block(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
@@ -132,7 +155,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.block(x=[1, 2, 3], y=[1,2,3], width=0.5, height=1, , color="#CAB2D6")
@@ -148,7 +171,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.circle_cross(x=[1,2,3], y=[4,5,6], size=20,
@@ -165,7 +188,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.circle_dot(x=[1,2,3], y=[4,5,6], size=20,
@@ -182,7 +205,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.circle_x(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -199,7 +222,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.circle_y(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -216,7 +239,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.cross(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -233,7 +256,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.dash(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -250,7 +273,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.diamond(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -267,7 +290,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.diamond_cross(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -284,7 +307,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.diamond_dot(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -301,7 +324,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.dot(x=[1, 2, 3], y=[1, 2, 3], size=20, color="#386CB0")
@@ -317,7 +340,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.harea(x1=[0, 0, 0], x2=[1, 4, 2], y=[1, 2, 3],
@@ -334,7 +357,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.harea_step(x1=[1, 2, 3], x2=[0, 0, 0], y=[1, 4, 2],
@@ -351,7 +374,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.hbar(y=[1, 2, 3], height=0.5, left=0, right=[1,2,3], color="#CAB2D6")
@@ -367,7 +390,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300, x_range=(0, 1))
         plot.hspan(y=[1, 2, 3], color="#CAB2D6")
@@ -383,7 +406,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300, x_range=(0, 1))
         plot.hstrip(y0=[1, 2, 5], y1=[3, 4, 8], color="#CAB2D6")
@@ -399,7 +422,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.ellipse(x=[1, 2, 3], y=[1, 2, 3], width=30, height=20,
@@ -416,7 +439,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.hex(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,30], color="#74ADD1")
@@ -432,7 +455,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.hex_dot(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,30],
@@ -449,7 +472,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300, match_aspect=True)
         plot.hex_tile(r=[0, 0, 1], q=[1, 2, 2], fill_color="#74ADD1")
@@ -492,7 +515,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.inverted_triangle(x=[1, 2, 3], y=[1, 2, 3], size=20, color="#DE2D26")
@@ -508,13 +531,42 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         p = figure(title="line", width=300, height=300)
         p.line(x=[1, 2, 3, 4, 5], y=[6, 7, 2, 4, 5])
 
         show(p)
 
+"""
+
+    @glyph_method(glyphs.MathMLGlyph)
+    def mathml(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, show
+
+        p = figure(width=300, height=300)
+        p.mathml(x=[0], y=[0], text=['''
+          <math display="block">
+            <mrow>
+              <msup>
+                <mi>x</mi>
+                <mn>2</mn>
+              </msup>
+              <msup>
+                <mi>y</mi>
+                <mn>2</mn>
+              </msup>
+            </mrow>
+          </math>
+        '''])
+
+        show(p)
+
 """
 
     @glyph_method(glyphs.MultiLine)
@@ -528,7 +580,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         p = figure(width=300, height=300)
         p.multi_line(xs=[[1, 2, 3], [2, 3, 4]], ys=[[6, 7, 2], [4, 5, 7]],
@@ -549,7 +601,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         p = figure(width=300, height=300)
         p.multi_polygons(xs=[[[[1, 1, 2, 2]]], [[[1, 1, 3], [1.5, 1.5, 2]]]],
@@ -557,6 +609,22 @@ Examples:
                         color=['red', 'green'])
         show(p)
 
+"""
+
+    @glyph_method(glyphs.Ngon)
+    def ngon(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, show
+
+        p = figure(width=300, height=300)
+        p.ngon(x=[1, 2, 3, 2], y=[6, 7, 2, 2], radius=1, n=[3, 4, 9, 20], color="#99d8c9")
+
+        show(p)
+
 """
 
     @glyph_method(glyphs.Patch)
@@ -566,7 +634,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         p = figure(width=300, height=300)
         p.patch(x=[1, 2, 3, 2], y=[6, 7, 2, 2], color="#99d8c9")
@@ -586,7 +654,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         p = figure(width=300, height=300)
         p.patches(xs=[[1,2,3],[4,5,6,5]], ys=[[1,2,1],[4,5,5,4]],
@@ -603,7 +671,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.plus(x=[1, 2, 3], y=[1, 2, 3], size=20, color="#DE2D26")
@@ -619,7 +687,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.quad(top=[2, 3, 4], bottom=[1, 2, 3], left=[1, 2, 3],
@@ -640,7 +708,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.ray(x=[1, 2, 3], y=[1, 2, 3], length=45, angle=-0.7, color="#FB8072",
@@ -657,7 +725,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.rect(x=[1, 2, 3], y=[1, 2, 3], width=10, height=20, color="#CAB2D6",
@@ -679,7 +747,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.step(x=[1, 2, 3, 4, 5], y=[1, 2, 3, 2, 5], color="#FB8072")
@@ -695,7 +763,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.segment(x0=[1, 2, 3], y0=[1, 2, 3],
@@ -713,7 +781,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.square(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,30], color="#74ADD1")
@@ -729,7 +797,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.square_cross(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -746,7 +814,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.square_dot(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -763,7 +831,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.square_pin(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -780,7 +848,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.square_x(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -797,7 +865,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.star(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -814,7 +882,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.star_dot(x=[1, 2, 3], y=[1, 2, 3], size=20,
@@ -822,6 +890,22 @@ Examples:
 
         show(plot)
 
+"""
+
+    @glyph_method(glyphs.TeXGlyph)
+    def tex(self, *args: Any, **kwargs: Any) -> GlyphRenderer:
+        """
+Examples:
+
+    .. code-block:: python
+
+        from bokeh.plotting import figure, show
+
+        p = figure(width=300, height=300)
+        p.tex(x=[0], y=[0], text=["x^2 y^2])
+
+        show(p)
+
 """
 
     @glyph_method(glyphs.Text)
@@ -840,7 +924,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.triangle(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -857,7 +941,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.triangle_dot(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -874,7 +958,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.triangle_pin(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,25],
@@ -891,7 +975,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.varea(x=[1, 2, 3], y1=[0, 0, 0], y2=[1, 4, 2],
@@ -908,7 +992,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.varea_step(x=[1, 2, 3], y1=[0, 0, 0], y2=[1, 4, 2],
@@ -925,7 +1009,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.vbar(x=[1, 2, 3], width=0.5, bottom=0, top=[1,2,3], color="#CAB2D6")
@@ -941,7 +1025,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300, y_range=(0, 1))
         plot.vspan(x=[1, 2, 3], color="#CAB2D6")
@@ -957,7 +1041,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300, y_range=(0, 1))
         plot.vstrip(x0=[1, 2, 5], x1=[3, 4, 8], color="#CAB2D6")
@@ -973,7 +1057,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.wedge(x=[1, 2, 3], y=[1, 2, 3], radius=15, start_angle=0.6,
@@ -990,7 +1074,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.x(x=[1, 2, 3], y=[1, 2, 3], size=[10, 20, 25], color="#fa9fb5")
@@ -1006,7 +1090,7 @@ Examples:
 
     .. code-block:: python
 
-        from bokeh.plotting import figure, output_file, show
+        from bokeh.plotting import figure, show
 
         plot = figure(width=300, height=300)
         plot.y(x=[1, 2, 3], y=[1, 2, 3], size=20, color="#DE2D26")
@@ -1046,12 +1130,6 @@ Examples:
             >>> p.scatter([1,2,3],[4,5,6], marker="square", fill_color="red")
             >>> p.scatter("data1", "data2", marker="mtype", source=data_source, ...)
 
-        .. note::
-            When passing ``marker="circle"`` it is also possible to supply a
-            ``radius`` value in |data units|. When configuring marker type
-            from a data source column, *all* markers including circles may only
-            be configured with ``size`` in |screen units|.
-
         .. note::
             ``Scatter`` markers with multiple marker types may be drawn in a
             different order when using the WebGL output backend. This is an explicit
@@ -1063,11 +1141,10 @@ Examples:
         if isinstance(marker_type, str) and marker_type in _MARKER_SHORTCUTS:
             marker_type = _MARKER_SHORTCUTS[marker_type]
 
-        # The original scatter implementation allowed circle scatters to set a
-        # radius. We will leave this here for compatibility but note that it
-        # only works when the marker type is "circle" (and not referencing a
-        # data source column). Consider deprecating in the future.
         if marker_type == "circle" and "radius" in kwargs:
+            deprecated((3, 4, 0), "scatter(radius=...)", "circle(radius=...) instead")
+            if "size" in kwargs:
+                raise ValueError("can only provide one of size or radius")
             return self.circle(*args, **kwargs)
         else:
             return self._scatter(*args, marker=marker_type, **kwargs)
