@@ -18,14 +18,11 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import TYPE_CHECKING, overload
+from typing import TypeAlias, overload
 
 # Bokeh imports
 from .warnings import BokehDeprecationWarning, warn
 
-if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
